@@ -281,7 +281,7 @@ struct sdr_record_mask {
 					uint16_t settable:8;
 #endif
 				} read;
-			};
+			} mask;
 		} threshold;
 	} type;
 } __attribute__ ((packed));
