@@ -78,8 +78,13 @@ extern void ipmi_lan_set_timeout(int ipmito, int tries, int pingto);
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil cmd";
+#else
+static char * progver   = "3.08";
 static char * progname  = "icmd";
+#endif
 static char   fdebug    = 0;
 static char   fquiet    = 0;
 static char   fset_mc   = 0;
