@@ -63,8 +63,13 @@
 #include "ifirewall.h"
 
 /* global variables */
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil firewall";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ifirewall";
-static char * progver   = "3.07";
+#endif
 static char   fdebug    = 0;
 static uchar  g_bus  = PUBLIC_BUS;
 static uchar  g_sa   = BMC_SA;
