@@ -105,8 +105,13 @@ extern void fmt_time(time_t etime, char *buf, int bufsz); /*see ievents.c*/
 #define IPROD_FRUID  6
 #define IPROD_OEM    7
 
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char *progname  = "ipmiutil fruset";
+#else
+static char * progver   = "3.12";
 static char *progname  = "ifruset";
-static char *progver   = "3.07";
+#endif
 static char fdebug = 0;
 static char fpicmg = 0;
 static char fonlybase = 0;
@@ -240,7 +245,7 @@ int
 load_fru(uchar sa, uchar frudev, uchar frutype)
 {
    int ret = 0;
-   uchar indata[16];
+   uchar indata[FRUCHUNK_SZ];
    uchar resp[18];
    int sresp;
    uchar cc;
@@ -250,6 +255,7 @@ load_fru(uchar sa, uchar frudev, uchar frutype)
    int i;
    int chunk;
 
+   memset(indata, 0, sizeof(indata));
    indata[0] = frudev;
    sresp = sizeof(resp);
    if (fdebug) printf("load_fru: sa = %02x, frudev = %02x\n",sa,frudev);
@@ -705,10 +711,14 @@ show_fru(uchar sa, uchar frudev, uchar frutype)
     */
    pfru = &frubuf[0];
    sz = 8;  /*minimum for common header*/
-   for (i = 1; i < 6; i++) 	/* walk thru offsets */
-	if (frubuf[i] != 0) sz = frubuf[i] * 8;
-   if (sz > 8)   		/* if have at least one section */
-      sz += frubuf[sz+1] * 8;   /* add length of last section */
+   for (i = 1; i < 6; i++) {	/* walk thru offsets */
+ 	 if (frubuf[i] != 0) sz = frubuf[i] * 8;
+   }
+   if (sz > 8) {   		/* if have at least one section */
+	 if (frubuf[5] != 0) j = 5 + frubuf[sz+2]; /*if multi-record area*/
+	 else j = frubuf[sz+1] * 8;   /* else add length of last section */
+	 sz += j;
+   }
    /* Now, sz = size used, sfru = total available size */
    if (sz > sfru) {
       if (fdebug) {
@@ -746,10 +756,11 @@ show_fru(uchar sa, uchar frudev, uchar frutype)
    mlen = 0;
    if (moff > 0) {
       for (i = moff; i < sfru; ) {
-	 j = 5 + frubuf[i+2];
+         if (frubuf[i] == 0 && frubuf[i+2] == 0) break; /*type/len invalid*/
+         j = 5 + frubuf[i+2];
          mlen += j; 
          if (frubuf[i+1] & 0x80) break;
-	 i += j;
+         i += j;
       }
    }
 
@@ -891,8 +902,9 @@ show_fru(uchar sa, uchar frudev, uchar frutype)
       j = moff;
       for (i = 0; j < sz; i++)
       {
+         if (pfru[0] == 0 && pfru[2] == 0) break; /*type/len invalid*/ 
          n = pfru[2];  /* len of this record */
-	 show_fru_multi(devstr,i,pfru[0],&pfru[5],n);
+         show_fru_multi(devstr,i,pfru[0],&pfru[5],n);
          j += (5 + n);
          if (pfru[1] & 0x80) j = sz;  /*0x80 = end of list*/
          pfru += (5 + n);
@@ -918,7 +930,7 @@ write_fru_data(uchar id, ushort offset, uchar *data, int dlen, char fdebug)
    int ret = -1;
    int chunk;
    ushort fruoff;
-   uchar req[25];
+   uchar req[FRUCHUNK_SZ+9];
    uchar resp[16];
    int sresp;
    uchar cc;
@@ -1215,7 +1227,7 @@ main(int argc, char **argv)
    char *s1;
    FILE *fp;
 
-   printf("%s: version %s\n",progname,progver);
+   printf("%s version %s\n",progname,progver);
    parse_lan_options('V',"4",0);  /*request admin priv by default*/
    while ( (c = getopt( argc, argv,"a:bcd:h:i:f:m:n:o:p:r:s:u:v:xyz:T:V:J:EYF:P:N:R:U:Z:?")) != EOF )
       switch(c) {
@@ -1361,7 +1373,7 @@ main(int argc, char **argv)
                 parse_lan_options(c,optarg,fdebug);
                 break;
           default:
-                printf("Usage: %s [-bcimx -unpvsafo -NUPREFTVY]\n",progname);
+                printf("Usage: %s [-bcimxy -unpvsafo -NUPREFTVY]\n",progname);
 		printf("   -u manu  Sets Product Manufacturer (0)\n");
 		printf("   -n name  Sets Product Name         (1)\n");
 		printf("   -p part  Sets Product Part Number  (2)\n");
@@ -1376,8 +1388,9 @@ main(int argc, char **argv)
 		printf("   -d       Dump FRU to a file\n");
 		printf("   -r       Restore FRU from a file\n");
 		printf("   -i 00    Get/Set a specific FRU ID\n");
-                printf("   -m002000 specific MC (bus 00,sa 20,lun 00)\n");
+        printf("   -m002000 specific MC (bus 00,sa 20,lun 00)\n");
 		printf("   -x       Display extra debug messages\n");
+		printf("   -y       Ignore the check for FRU size overflow\n");
 		print_lan_opt_usage(0);
                 ret = ERR_USAGE;
 		goto do_exit;
@@ -1561,7 +1574,11 @@ main(int argc, char **argv)
 
    if (fdump && ret == 0) {
       /* Dump FRU to a binary file */
+#ifdef WIN32
+      fp = fopen(binfile,"wb");
+#else
       fp = fopen(binfile,"w");
+#endif
       if (fp == NULL) {
          ret = get_LastError();
          printf("Cannot open file %s, error %d\n",binfile,ret);
@@ -1577,9 +1594,13 @@ main(int argc, char **argv)
    } else if (frestore) {
       uchar cksum;
       /* Restore FRU from a binary file */
+#ifdef WIN32
+      fp = fopen(binfile,"rb");
+#else
       fp = fopen(binfile,"r");
+#endif
       if (fp == NULL) {
-	 ret = get_LastError();
+         ret = get_LastError();
          printf("Cannot open file %s, error %d\n",binfile,ret);
       } else {
 	 ret = 0;
