@@ -82,8 +82,13 @@ extern int oem_supermicro_get_firmware_str(char *pstr, int sz); /*oem_supermicro
 /*
  * Global variables 
  */
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil health";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ihealth";
-static char * progver   = "3.07";
+#endif
 static char   fdebug    = 0;
 static char   fipmilan  = 0;
 static char   fcanonical = 0;
