@@ -65,6 +65,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /* see ipmicmd.h for LAN_ERR definitions */
 
+int get_LastError( void );
+void show_LastError(char *tag, int err);
+void ipmi_lan_set_timeout(int ipmito, int tries, int pingto);
 int ipmi_open_lan(char *node, int port, char *user, char *pswd, int fdebugcmd);
 int ipmi_close_lan(char *node);
 int ipmi_flush_lan(char *node);
