@@ -142,7 +142,7 @@ extern void tty_setnormal(int mode);   /*from ipmicmd.c*/
 extern SockType lan_get_fd(void);          /*from ipmilan.c*/
 extern int  lan_send_sol( uchar *payload, int len, SOL_RSP_PKT *rsp);
 extern int  lan_recv_sol( SOL_RSP_PKT *rsp );
-extern int  lan_keepalive(int type);
+extern int  lan_keepalive(uchar type);
 extern void lan_get_sol_data(uchar fEnc, uchar iseed, uint32 *seed);
 extern void lan_set_sol_data(uchar fEnc, uchar auth, uchar iseed, 
 				int insize, int outsize);
