@@ -118,9 +118,9 @@ static SOCKADDR_T haddr;
 static int haddrlen = 0;
 static int hauth, hpriv, hcipher;
 #ifdef WIN32
-#define NI_MAXHOST 80
-#define NI_MAXSERV 80
-struct pollfd { int fd; short events; short revents; };
+// #define NI_MAXHOST 80
+// #define NI_MAXSERV 80
+// struct pollfd { int fd; short events; short revents; };
 struct winsize { int x; int y; };
 #else
 static struct termios _saved_tio;
@@ -499,7 +499,7 @@ ipmi_tsol_main(void * intf, int  argc, char ** argv)
 	}
 
 	get_lan_options(hostname,NULL,NULL,&hauth, &hpriv, &hcipher,NULL,NULL);
-        result = open_sockfd(hostname, &sockfd, &haddr, &haddrlen, 1);
+        result = open_sockfd(hostname, port, &sockfd, &haddr, &haddrlen, 1);
 	if (result) {
 		lperror(LOG_ERR, "Connect to %s failed",hostname);
 		return result;
