@@ -100,8 +100,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil wdt";
+#else
+static char * progver   = "3.08";
 static char * progname  = "iwdt";
+#endif
 static char   fdebug    = 0;
 static char   fdontlog  = 0;
 static char   fcanonical = 0;
