@@ -52,8 +52,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /* extern void get_mfgid(int *vend, int *prod);  * from ipmicmd.h*/
 /* extern int get_lan_options();  * from ipmicmd.h */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil fujitsuoem";
+#else
+static char * progver   = "3.08";
 static char * progname  = "ifujitsuoem";
+#endif
 static char fdebug = 0;
 static char freadok = 1;
 #define ERRLED    0  /*GEL - red  Global Error LED*/
